import { PlusOutlined } from '@ant-design/icons';
import type {
  ActionType,
  ProColumns,
  ProFormInstance,
} from '@ant-design/pro-components';
import {
  ProCard,
  ProTable,
} from '@ant-design/pro-components';
import { Button, message, Popconfirm, Space } from 'antd';
import { useState, useRef } from 'react';
//引入接口
import dayjs from 'dayjs'
import processApi from '@/api/process/service'

export default () => {
  const [fromType, setFromType] = useState<any>('table')
  const ref = useRef<ProFormInstance>();
  const actionRef = useRef<ActionType>();

  const Reolod = () =>{
    ref.current?.resetFields()
    actionRef.current?.reload()
  }
  const columns: ProColumns<processType.output>[] = [
    {
      title: '主键',
      dataIndex: 'id',
      width: 160,
      hideInForm: true,
      hideInSearch:true
    },
    {
      title: '名称',
      dataIndex: 'name',
      ellipsis: true,
      width: 120,
      formItemProps:{
        rules:[{ required: true, message: '此项为必填项!' }]
      }
    },
    {
      title: '类型',
      hideInDescriptions: true,
      dataIndex: 'processType',
      width: 120,
      search: false,
      valueEnum:{
        0: {
          text: '人工',
         
      },
      1: {
          text: '设备',
         
      },
      },
      formItemProps:{
        rules:[{ required: true, message: '此项为必填项!' }]
      }
    },
    {
      title: '描述',
      dataIndex: 'des',
  
      search: false,
    },
    {
      title: '创建时间',
      dataIndex: 'createTime',
      render: (_, record) => {
        return <>{dayjs(record.createTime).format("YYYY-MM-DD HH:mm:ss")}</>
      },
      search: false,
      hideInForm:true
    },
    {
      title: '操作',
      valueType: 'option',
      dataIndex: 'id',
      render: (text, row) => [
        <Space key={+new Date() + Math.random()}>
          <a  onClick={() => {
             setFromType('form')
            ref.current?.setFieldsValue(row)
          }} key={+new Date() + Math.random()} target="_blank" rel="noopener noreferrer">
            编辑
          </a>
          <Popconfirm
           key="del"
           title="确定要删除此条数据吗？"
           onConfirm={() => {
          
            processApi.Del(row).then((res: MyResponse.Content) => {
              if (res.statusCode === 200) {
                message.info("删除成功!");
                Reolod()
              } else {
                message.error(res.errors);
              }
            })
          }}
          onCancel={() => {
            message.info('已取消删除');
          }}
          okText="确认"
          cancelText="关闭"
        > 
          <a> 
            删除
          </a>
          </Popconfirm>
        </Space>
      ],
    },
  ];

  return (
    <>
     
        {/* {fromType === 'form' ? <Button type='primary' onClick={() =>{
           ref.current?.resetFields();
          setFromType("table")}}>返回</Button> : ""} */}
        <ProTable<processType.output>
        
          columns={columns}
       
          type={fromType as 'table'}
          formRef={ref}
          actionRef={actionRef}
          onSubmit={(params: any) => {
            console.log(params);
            if (fromType === 'form') {
              if (params.id) {
                processApi.Update(params).then((res: MyResponse.Content) => {
                  if (res.statusCode === 200) {
                    message.info("更新成功!");
                    setFromType('table')
                    Reolod()
                  } else {
                    message.error(res.errors);
                  }
                })
              } else {
                processApi.Add(params).then((res: MyResponse.Content) => {
                  if (res.statusCode === 200) {
                    message.info("新增成功!");
                    setFromType('table')
                    Reolod()
                  } else {
                    message.error(res.errors);
                  }
                })
              }
            }
          }}
         
          form={{ignoreRules:true,// 自定义提交按钮的属性
            submitter: {
              onReset:()=>{
                ref.current?.resetFields()
                setFromType("table")
              },
             searchConfig: { resetText: fromType === 'form' ? '返回': '重置'}, }
           }}
          request={async (params = {}) => {
            const jsonData: processType.queryPage = {
              pageIndex: params.current || 1,
              pageSize: params.pageSize || 10,
              name: params.name || '',
            };
            const response = await processApi.PagedList(jsonData);
            if (response.statusCode === 200) {
              return {
                data: response.data.items,
                success: true,
                total: response.data.total,
              };
            } else {
              return {
                data: [],
                success: false,
                total: 0,
              };
            }
          }}
          pagination={{
            pageSize: 10,
            showSizeChanger:false
          }}
          rowKey="id"
          dateFormatter="string"
          headerTitle="列表"
          toolBarRender={() => [
            <Button key="3" type="primary" onClick={() => {
              setFromType('form');
            }}>
              <PlusOutlined />
              新建
            </Button>,
          ]}
        />
      
    </>
  );
};